<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */
use fid\Hydrator\UserHydrator;
use Zend\Filter\Boolean;
use Zend\Filter\StringTrim;
use Zend\Form\Element\Checkbox;
use Zend\Form\Element\Email;
use Zend\Form\Element\Submit;
use Zend\Form\Element\Text;
use Zend\Validator\EmailAddress;
use Zend\Validator\Identical;
use Zend\Validator\NotEmpty;
use Zend\Validator\Regex;
use Zend\Validator\StringLength;

return [
    'name'         => 'user-init-form',
    'hydrator'     => UserHydrator::class,
    'elements'     => [
        'username'             => [
            'spec' => [
                'id'       => 'username',
                'name'       => 'username',
                'type'       => Email::class,
                'options'    => [
                    'label' => 'label_username',
                ],
                'attributes' => [
                    'required' => true,
                    'autocomplete' => 'email'
                ],
            ],
        ],
        'username_confirmation' => [
            'spec' => [
                'id'       => 'username_confirmation',
                'name'       => 'username_confirmation',
                'type'       => Email::class,
                'options'    => [
                    'label' => 'label_username_confirmation',
                ],
                'attributes' => [
                    'required' => true,
                    'autocomplete' => 'email'
                ],
            ],
        ],
        'firstname'            => [
            'spec' => [
                'name'       => 'firstname',
                'type'       => Text::class,
                'options'    => [
                    'label' => 'label_firstname',
                ],
                'attributes' => [
                    'required' => true,
                    'autocomplete' => "given-name"
                ],
            ],
        ],
        'lastname'             => [
            'spec' => [
                'name'       => 'lastname',
                'type'       => Text::class,
                'options'    => [
                    'label' => 'label_lastname',
                ],
                'attributes' => [
                    'required' => true,
                    'autocomplete' => "family-name"
                ],
            ],
        ],
        'eula_accepted'         => [
            'spec' => [
                'name'       => 'eula_accepted',
                'type'       => Checkbox::class,
                'attributes' => [
                    'required' => true,
                ],
            ],
        ],
        'submit'               => [
            'spec' => [
                'name'       => 'submit',
                'type'       => Submit::class,
                'attributes' => [
                    'value' => 'label_submit',
                ],
            ],
        ],
    ],
    'input_filter' => [
        'username'             => [
            'name'       => 'username',
            'required'   => true,
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 255
                    ],
                ],
                EmailAddress::class => [
                    'name' => EmailAddress::class,
                ],
            ],
        ],
        'username_confirmation' => [
            'name'       => 'username_confirmation',
            'required'   => true,
            'validators' => [
                Identical::class => [
                    'name'    => Identical::class,
                    'options' => [
                        'strict'   => false,
                        'token'    => 'username',
                        'messages' => [
                            Identical::NOT_SAME => 'error_username_confirmation',
                        ],
                    ],
                ],
            ],
        ],
        'firstname'            => [
            'name'       => 'firstname',
            'required'   => true,
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 255
                    ]
                ],
                Regex::class        => [
                    'name'    => Regex::class,
                    'options' => [
                        'pattern' => '/^\D*$/',
                    ],
                ],
            ],
        ],
        'lastname'             => [
            'name'       => 'lastname',
            'required'   => true,
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'max' => 255
                    ]
                ],
                Regex::class        => [
                    'name'    => Regex::class,
                    'options' => [
                        'pattern' => '/^\D*$/',
                    ],
                ],
            ],
        ],
        'eula_accepted'         => [
            'name'       => 'eula_accepted',
            'required'   => true,
            'filters'    => [
                Boolean::class => [
                    'name' => Boolean::class,
                ],
            ],
            'validators' => [
                NotEmpty::class => [
                    'name'    => NotEmpty::class,
                    'options' => [
                        'messages' => [
                            NotEmpty::IS_EMPTY => 'error_eula_accepted',
                        ],
                    ],
                ],
            ],
        ],
        'submit'               => [
            'name'     => 'submit',
            'required' => true,
        ],
    ],
];
