<?php
/**
 * Order missing record hydrator
 *
 * Copyright (C) 2021 Leipzig University Library
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Hydrator
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Hydrator;

use fid\Service\DataTransferObject\Order;
use Zend\Hydrator\AbstractHydrator;

/**
 * Order missing record (free/ open digitization-on-demand) hydrator
 * for saving aquistions data correctly before sending to fidis.
 *
 * @category VuFind
 * @package  Hydrator
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
class OrderMissingRecordHydrator extends AbstractHydrator
{
    /**
     * Extract method:
     * Not implemented, not in use
     *
     * @param Order $object Order object
     *
     * @return void
     */
    public function extract($object)
    {
    }

    /**
     * Save free/ open digitization-on-demand data to order object
     *
     * @param array $data   Data to hydrate
     * @param Order $object Order object
     *
     * @return Order
     */
    public function hydrate(array $data, $object)
    {
        $object->setType($data['type']);
        $object->setUser($data['user']);

        $digitization
            = array_key_exists('digitization', $data) ? $data['digitization'] : null;
        $partialCopy = null;
        $pda = null;
        $record = null;

        $object->setData(compact('record', 'partialCopy', 'digitization', 'pda'));
        $object->setStatus($data['status']);
        $object->setLabel($data['label']);
    }
}
