<?php
/**
 * User data strategy
 *
 * Copyright (C) 2019 Leipzig University Library
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Hydrator
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Hydrator\Strategy;

use fid\Hydrator\UserHydrator;
use fid\Hydrator\UserHydratorDelegatorFactory;
use Zend\Hydrator\NamingStrategy\NamingStrategyInterface;
use Zend\Hydrator\Strategy\StrategyInterface;

/**
 * User data strategy
 *
 * @category VuFind
 * @package  Hydrator
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 *
 * @see UserHydrator
 * @see UserHydratorDelegatorFactory
 */
class UserDataStrategy implements StrategyInterface
{
    /* @var NamingStrategyInterface */
    protected $namingStrategy;

    /**
     * Constructor
     *
     * @param NamingStrategyInterface $namingStrategy Naming Startegy
     */
    public function __construct(NamingStrategyInterface $namingStrategy)
    {
        $this->namingStrategy = $namingStrategy;
    }

    /**
     * Extract method
     *
     * @param array|mixed $value Value(s)
     *
     * @return array|mixed
     */
    public function extract($value)
    {
        if (!is_array($value)) {
            return $value;
        }

        foreach ($value as $key => $val) {
            $name = $this->namingStrategy->extract($key);
            $result[$name] = $this->extract($val);
        }

        return $result ?? [];
    }

    /**
     * Hydrate method
     *
     * @param array|mixed $value Value(s)
     *
     * @return array|mixed
     */
    public function hydrate($value)
    {
        if (!is_array($value)) {
            return $value;
        }

        foreach ($value as $key => $val) {
            $name = $this->namingStrategy->hydrate($key);
            $result[$name] = $this->hydrate($val);
        }

        return $result ?? [];
    }
}
