<?php
/**
 * Root aware base input filter
 *
 * Copyright (C) 2019 Leipzig University Library
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Input_Filter
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\InputFilter;

use Zend\InputFilter\BaseInputFilter;

/**
 * Root aware base input filter
 *
 * @category VuFind
 * @package  Input_Filter
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
class RootAwareBaseInputFilter extends BaseInputFilter
{
    public const ROOT = '__ROOT__';

    /**
     * {@inheritdoc}
     *
     * @param mixed|null $context Context
     *
     * @return bool
     */
    public function isValid($context = null)
    {
        $values = array_merge($this->getRawValues(), (array)$this->data);
        $values[self::ROOT] = $context[self::ROOT] ?? $this;

        return parent::isValid($values);
    }
}
