<?php
/**
 * Locale listener
 *
 * Copyright (C) 2019 Leipzig University Library
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Listener
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Listener;

use fid\Service\Client;
use Zend\EventManager\AbstractListenerAggregate;
use Zend\EventManager\EventManagerInterface;
use Zend\Log\Filter\Priority;
use Zend\Mvc\I18n\Translator;
use Zend\Mvc\MvcEvent;

/**
 * Locale listener
 *
 * @category VuFind
 * @package  Listener
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
class LocaleListener extends AbstractListenerAggregate
{
    protected const EVENT = MvcEvent::EVENT_DISPATCH;

    /**
     * Attach onDispatch method to event (MvcEvent::EVENT_DISPATCH)
     *
     * @param EventManagerInterface $events   Event manager
     * @param $priority Used priority
     *
     * @return void
     */
    public function attach(EventManagerInterface $events, $priority = 9000)
    {
        $events->attach(static::EVENT, [$this, 'onDispatch'], $priority);
    }

    /**
     * Set fidis clients locale
     *
     * @param MvcEvent $event Event
     *
     * @return void
     */
    public function onDispatch(MvcEvent $event)
    {
        $container = $event->getApplication()->getServiceManager();
        /* @var Client $client */
        $client = $container->get(Client::class);
        $locale = $container->get(Translator::class)->getLocale();
        $client->setLocale($locale);
    }
}
