<?php
/**
 * Fidis client factory
 *
 * Copyright (C) 2019 Leipzig University Library
 *
 * PHP version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Service
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Service;

use fid\Listener\ClientConfigListener;
use Psr\Container\ContainerInterface;
use Psr\Http\Client\ClientInterface as HttpClientInterface;
use Psr\Http\Message\RequestFactoryInterface;
use Psr\Http\Message\StreamFactoryInterface;
use Psr\Http\Message\UriFactoryInterface;
use Symfony\Component\Serializer\SerializerInterface;
use VuFind\Cookie\CookieManager;
use Zend\Session\Container as Session;
use Zend\Session\SessionManager;

/**
 * FID client factory class
 *
 * @category VuFind
 * @package  Service
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class ClientFactory
{
    /**
     * Invoke Client
     *
     * @param ContainerInterface $container container
     *
     * @return Client
     */
    public function __invoke(ContainerInterface $container): Client
    {
        /* @var ClientConfigListener $clientConfigListener */
        $clientConfigListener = $container->get(ClientConfigListener::class);
        /* @var SessionManager $sessionManager */
        $sessionManager = $container->get(SessionManager::class);
        $session = new Session(Client::class, $sessionManager);
        /* @var CookieManager $cookies */
        $cookies = $container->get(CookieManager::class);
        /* @var SerializerInterface $serializer */
        $serializer = $container->get(SerializerInterface::class);
        /* @var HttpClientInterface $httpClient */
        $httpClient = $container->get(HttpClientInterface::class);
        /* @var UriFactoryInterface $uriFactory */
        $uriFactory = $container->get(UriFactoryInterface::class);
        /* @var StreamFactoryInterface $streamFactory */
        $streamFactory = $container->get(StreamFactoryInterface::class);
        /* @var RequestFactoryInterface $requestFactory */
        $requestFactory = $container->get(RequestFactoryInterface::class);

        return new Client(
            $clientConfigListener->getConfig(),
            $session,
            $cookies,
            $serializer,
            $httpClient,
            $uriFactory,
            $streamFactory,
            $requestFactory
        );
    }
}
