<?php
/**
 * Subito partial copy page bounds validator
 *
 * Copyright (C) 2020 Leipzig University Library
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Validator
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Validator;

use Zend\Validator\AbstractValidator;

/**
 * Subito partial copy page bounds validator
 *
 * @category VuFind
 * @package  Validator
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
class SubitoPartialCopyPageBounds extends AbstractValidator
{
    use SubitoPartialCopyPageRangeValidatorTrait;

    public const PAGE_BOUNDS = 'subitoPartialCopyPageBounds';

    // Available validator options.
    protected $options = [
        'numberPages' => null
    ];

    protected $messageTemplates = [
        self::PAGE_BOUNDS => "acquisition_error_page_bounds",
    ];

    /**
     * Validate if given page range is beetween first and last page of a record
     *
     * @param string $value From to page range
     *
     * @return bool
     */
    public function isValid($value) : bool
    {
        if ($this->options['numberPages'] == null) {
            return false;
        }
        $this->_extractPages($value);

        if (($this->_pageEnd > $this->options['numberPages'])
            || ($this->_pageStart < 1)
        ) {
            $this->error(self::PAGE_BOUNDS);
            return false;
        } else {
            return true;
        }
    }
}
