<?php
/**
 * Factory for Root view helpers.
 *
 * PHP version 5
 *
 * Copyright (C) Villanova University 2014.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\View\Helper\Root;

use fid\Service\Client;
use Interop\Container\ContainerInterface;

/**
 * Factory for Root view helpers.
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class Factory
{
    /**
     * Construct the Record helper.
     *
     * @param ContainerInterface $container Service manager.
     *
     * @return UserGroups
     */
    public static function getUserGroups(ContainerInterface $container)
    {
        return new UserGroups(
            $container->get('VuFind\Config')->get('fid')
        );
    }

    /**
     * Construct the Record helper.
     *
     * @param ContainerInterface $container Service manager.
     *
     * @return GetIt
     */
    public static function getGetIt(ContainerInterface $container)
    {
        return new GetIt(
            $container->get('VuFind\Config')->get('getit'),
            $container->get(Client::class),
            $container->get('VuFind\Role\PermissionManager')
        );
    }
}
