<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

use fid_adlr\InputFilter\UserUpdateFormInputFilter;
use Zend\Filter\Boolean;
use Zend\Filter\StringTrim;
use Zend\Filter\ToInt;
use Zend\Form\Element\Checkbox;
use Zend\Form\Element\Select;
use Zend\Form\Element\Tel;
use Zend\Validator\NotEmpty;
use Zend\Validator\StringLength;

return [
    'elements'     => [
        'job_title' => [
            'spec' => [
                'name'       => 'job_title',
                'type'       => Select::class,
                'options'    => [
                    'label'         => 'label_job_title',
                    'value_options' => [
                        'job_title_0',
                        'job_title_1',
                        'job_title_2',
                        'job_title_3',
                        'job_title_4',
                        'job_title_5',
                        'job_title_6',
                        'job_title_7',
                        'job_title_8',
                        'job_title_9',
                    ],
                ],
                'attributes' => [
                    'disabled' => true,
                ],
            ],
        ],
        'college'   => [
            'spec' => [
                'attributes' => [
                    'required' => true,
                ],
            ],
        ],
        'addresses' => require 'address-collection.php',
        'data'      => [
            'spec' => [
                'elements' => [
                    'phone'            => [
                        'spec' => [
                            'name'    => 'phone',
                            'type'    => Tel::class,
                            'options' => [
                                'label' => 'label_phone',
                            ],
                            'attributes' => [
                                'autocomplete' => 'tel',
                            ]
                        ],
                    ],
                    'newsletter'       => [
                        'spec' => [
                            'name'    => 'newsletter',
                            'type'    => Checkbox::class,
                            'options' => [
                                'label' => 'label_newsletter',
                            ],
                        ],
                    ],
                    'delivery_address' => [
                        'spec' => [
                            'name'    => 'delivery_address',
                            'type'    => Checkbox::class,
                            'options' => [
                                'label' => 'label_delivery_address',
                            ],
                        ],
                    ],
                ],
                'options'  => [
                    'input_filter_spec' => [
                        'phone'            => [
                            'name'       => 'phone',
                            'required'   => false,
                            'filters'    => [
                                StringTrim::class => [
                                    'name' => StringTrim::class,
                                ],
                            ],
                            'validators' => [
                                StringLength::class => [
                                    'name'    => StringLength::class,
                                    'options' => [
                                        'max' => 255
                                    ],
                                ],
                            ],
                        ],
                        'newsletter'       => [
                            'name'       => 'newsletter',
                            'filters'    => [
                                Boolean::class => [
                                    'name' => Boolean::class,
                                ],
                            ],
                            'validators' => [
                                NotEmpty::class => [
                                    'name'    => NotEmpty::class,
                                    'options' => [
                                        'type' => NotEmpty::NULL,
                                    ],
                                ],
                            ],
                        ],
                        'delivery_address' => [
                            'name'       => 'delivery_address',
                            'filters'    => [
                                ToInt::class => [
                                    'name' => ToInt::class,
                                ],
                            ],
                            'validators' => [
                                NotEmpty::class => [
                                    'name'    => NotEmpty::class,
                                    'options' => [
                                        'type' => NotEmpty::NULL,
                                    ],
                                ],
                            ],
                        ],
                    ],
                ],
            ],
        ],
    ],
    'input_filter' => [
        'type'      => UserUpdateFormInputFilter::class,
        'job_title' => [
            'required' => false,
        ],
        'college'   => [
            'required' => true,
        ],
    ],
];
