<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */
namespace fid_adlr\Controller;

use fid\Validator\SubitoPartialCopyPageBounds;
use fid\Validator\SubitoPartialCopyPageSelection;
use Zend\Session\Container;

class RecordController extends \fid\Controller\RecordController
{
    /**
     * @var Container
     */
    protected $session;

    /**
     * @param Container $session
     */
    public function setSession($session): void
    {
        $this->session = $session;
    }

    /**
     * @var bool $wasWarned
     */
    protected $wasWarned;

    protected function getOrderLabel()
    {
        return $this->getRecordCitation();
    }

    protected function addOptinalFormValidators($form)
    {
        if ($this->type == self::SUBITO_PARTIAL_COPY) {
            // add number of pages specific validators
            $recordPages = $this->loadRecord()->tryMethod('getNumberOfPages');
            if ($recordPages) {
                $form->getInputFilter()->get('pages')->getValidatorChain()->attach(
                    new SubitoPartialCopyPageBounds(['numberPages' => $recordPages]),
                    true
                );

                // check if to pause selection validation for case that wrong warning message was thrown
                if (!(isset($this->session->wrongSelection) && $this->session->wrongSelection == $this->getRequest()->getPost()->get('pages'))) {
                    $form->getInputFilter()->get('pages')->getValidatorChain()->attach(
                        new SubitoPartialCopyPageSelection(['numberPages' => $recordPages])
                    );
                    $this->wasWarned = false;
                } else {
                    $this->wasWarned = true;
                }
                unset($this->session->wrongSelection);
            }
        }
    }

    protected function handleOptionalErrorMessages($form)
    {
        if ($this->type == self::SUBITO_PARTIAL_COPY) {
            if ($errors = $form->getInputFilter()->get('pages')->getValidatorChain()->getMessages()) {
                if (sizeof($errors) == 1 && array_key_exists(SubitoPartialCopyPageSelection::PAGE_SELECTION, $errors)) {
                    $this->session->wrongSelection = $this->getRequest()->getPost()->get('pages');
                }
            }
        }
    }

    protected function addTypeSpecificOrderInformation($form)
    {
        $data = parent::addTypeSpecificOrderInformation($form);
        if ($this->type == self::SUBITO_PARTIAL_COPY) {
            $data['subitoPartialCopy']['warning'] = $this->wasWarned;
        }
        return $data;
    }
}
