<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

namespace fid_adlr\Helper;

use DOMDocument;
use Zend\View\Helper\AbstractHelper;

class Rss extends AbstractHelper
{
    /**
     * @param array of rss origin data
     * @return array of rss feeds
     */
    public function load($rssOrigin)
    {
        $baseUrl    = $rssOrigin["base_url"] ?? "";
        $fallback   = $rssOrigin["fallback_url"] ?? "";
        $docPath    = $rssOrigin["xml_doc"] ?? "";

        $rssDoc = new DOMDocument();
        $feeds = array();
        try {
            if ($rssDoc->load($baseUrl . '/' . $docPath)) {
                $limit = 3;
                $n = 0;

                foreach ($rssDoc->getElementsByTagName('item') as $node) {
                    $item = array(
                        'title' => $node->getElementsByTagName('title')->item(0)->nodeValue,
                        'link' => $node->getElementsByTagName('link')->item(0)->nodeValue
                    );
                    array_push($feeds, $item);

                    if (++$n >= $limit) {
                        break;
                    }
                }
            }
        } catch (\Exception $ex) {
            if ($fallback) {
                $item = array(
                    'title' => $fallback,
                    'link' => $fallback
                );
                array_push($feeds, $item);
            }
        }

        return $feeds;
    }
}
