<?php
/**
 * "Get Additional Account Info" AJAX handler
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library 2019.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  AJAX
 * @author   Frank Morgner <morgnerf@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace finc\AjaxHandler;

use Zend\Mvc\Controller\Plugin\Params;

/**
 * AJAX handler to count items for view
 *
 * Get additional account infos
 *
 * @category VuFind
 * @package  AJAX
 * @author   Frank Morgner <morgnerf@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class GetAdditionalAccountInfo extends \VuFind\AjaxHandler\AbstractIlsAndUserAction
{
    /**
     * Get additional information for display in my research area.
     *
     * This method currently only returns the items/entries count of the ILS methods
     * given as post values.
     *
     * @param Params $params Parameter helper from controller
     *
     * @return array [response data, HTTP status code]
     */
    public function handleRequest(Params $params)
    {
        $this->disableSessionWrites();  // avoid session write timing bug
        // collect data for views to be counted
        $viewsToCount = $params()->fromQuery('views');

        try {
            $patron = $this->ilsAuthenticator->storedCatalogLogin();
            if ($patron) {
                $countViewItems = $this->ils->countItems(
                    $viewsToCount,
                    $patron
                );
                
                /* #21313 use vufind code of account_ajax.js for fines
                $countFines = $this->ils->getFinesTotal(
                    $patron
                );
                */

                return $this->formatResponse(compact('countViewItems'));
            }
        } catch (\Exception $e) {
            // Do nothing -- just fail through to the error message below.
        }
        return $this->formatResponse(
            $this->translate('An error has occurred'),
            self::STATUS_HTTP_ERROR
        );
    }
}
