<?php
/**
 * PHP version 5
 *
 * Copyright (C) Villanova University 2010.
 * Copyright (C) project swissbib, University Library Basel, Switzerland
 * Copyright (C) Leipzig University Library 2015.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  finc
 * @author   Guenter Hipler <guenter.hipler@unibas.ch>
 * @author   Frank Morgner  <morgnerf@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://www.swissbib.org
 */
namespace fincTest\RecordDriver;

use finc\RecordDriver\SolrMarcFinc as SolrMarcFincDriver;
use finc\RecordDriver\SolrMarcFincTrait;
use VuFindTest\Unit\TestCase as VuFindTestCase;

/**
 * SolrMarcTestCase
 *
 * @category VuFind
 * @package  finc
 * @author   Guenter Hipler  <guenter.hipler@unibas.ch>
 * @author   Frank Morgner  <morgnerf@ub.uni-leipzig.de>
 * @author   Robert Lange  <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://vufind.org
 */
class SolrMarcFincTestCase extends VuFindTestCase
{
    /**
     * SolrMarcDriver
     *
     * @var SolrMarcFincDriver
     */
    protected $driver;

    /**
     * Initialize driver with fixture
     *
     * @param String $file File
     *
     * @return void
     */
    public function initialize($file)
    {
        if (!$this->driver) {
            $this->driver = new SolrMarcFincDriver();
            $fixture = $this->getFixtureData($file);
            $this->driver->setRawData($fixture);
        }
    }

    /**
     * Get record fixture
     *
     * @param String $file File
     *
     * @return array
     */
    protected function getFixtureData($file, $decode = true)
    {
        $content = file_get_contents(realpath(FINC_TEST_FIXTURES . '/' . $file));
        return $decode ? json_decode($content, true) : $content;
    }

    /**
     * @return void
     */
    public function testGetURLs()
    {
        // although not current isil, link for IIIF should be shown based on indicator 2 #20600
        $this->runGetURLsTestCase('IIIF_0-1763648745');
        $this->runGetURLsTestCase('IIIF_0-1763648745', ['DE-15']);

        // Record 0-1497294835 with isil of DE-15 in fullrecord (subfield 9) results in empty array for adlr #18915
        $this->runGetURLsTestCase('isil_with_DE-15_0-1497294835', ['DE-15-FID'], []);
        $this->runGetURLsTestCase('isil_with_DE-15_0-1497294835', ['FID-MEDIEN-DE-15'], []);
        // .. but is shown in DE-15
        $this->runGetURLsTestCase('isil_with_DE-15_0-1497294835', ['DE-15']);

        // Record 0-1497294835 has no given isil in fullrecord (subfield 9) => shown as default / fallback #18915
        $this->runGetURLsTestCase('no_isil_for_22-15-qucosa-161943', ['DE-15-FID']);
        $this->runGetURLsTestCase('no_isil_for_22-15-qucosa-161943', ['DE-15']);
    }

    protected function getDriverMock()
    {
        return new SolrMarcFincDriverMock();
    }

    /**
     * @return void
     */
    public function runGetURLsTestCase(string $testCase, array $isils = [], $expectedResult = null)
    {
        $driver = $this->getDriverMock();
        $driver->setFullRecord($this->getFixtureData("getUrls/{$testCase}_fullrecord.txt", false));
        $driver->setIsils($isils);
        $actualResult = $driver->getURLs();
        $expectedResult = $expectedResult ?? $this->getFixtureData("/getUrls/{$testCase}_result.json");
        $this->assertEquals($expectedResult, $actualResult);
    }
}

class SolrMarcFincDriverMock extends SolrMarcFincDriver
{
    use SolrMarcFincTrait;

    public function setFullRecord(string $fullrecord)
    {
        $this->fields['fullrecord'] = $fullrecord;
    }

    public function setIsils(array $isils)
    {
        $this->isil = $isils;
    }
}
